<?php

namespace FiloBlu\Storelocator\Helper;

class Data extends \Magento\Framework\App\Helper\AbstractHelper
{
    const CONFIG_IMAGE_DIR_PREFIX = 'filoblu/storelocator/';
    const STORES_IMAGE_DIR_PREFIX = 'filoblu/storelocator/stores/image/';

    protected $_storeManager;

    public function __construct(\Magento\Framework\App\Helper\Context $context,
                                \Magento\Store\Model\StoreManagerInterface $storeManager,
                                \Magento\Framework\View\Asset\Repository $assetRepo
    ) {
        $this->_storeManager = $storeManager;
        $this->scopeConfig = $context->getScopeConfig();
        $this->assetRepo = $assetRepo;
        $this->request = $context->getRequest();
        $this->urlBuilder = $context->getUrlBuilder();
    }

    public function getConfig($config_path)
    {
        return $this->scopeConfig->getValue(
            $config_path,
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE
        );
    }

    public function geocode($address)
    {
        // url encode the address
        $address = urlencode($address);

        // google map geocode api url
        $key = $this->getConfig('filoblu_storelocator_section/general/gmaps_api_key_server_side');
        $url = $this->getConfig('filoblu_storelocator_section/geocode/gmaps_geocode_api_url') . "?address={$address}&key={$key}";

        // get the json response
        $resp_json = file_get_contents($url);

        // decode the json
        $resp = json_decode($resp_json, true);

        // response status will be 'OK', if able to geocode given address
        if ($resp['status'] == 'OK') {

            // get the important data
            $lati = $resp['results'][0]['geometry']['location']['lat'];
            $longi = $resp['results'][0]['geometry']['location']['lng'];
            $formatted_address = $resp['results'][0]['formatted_address'];

            // verify if data is complete
            if ($lati && $longi && $formatted_address) {

                // put the data in the array
                $data_arr = array();

                array_push(
                    $data_arr,
                    $lati,
                    $longi,
                    $formatted_address
                );

                return $data_arr;

            } else {
                return false;
            }

        } else {
            return false;
        }
    }

    public function getBaseUrlConfigImage()
    {
        return $this->_storeManager->getStore()->getBaseUrl(\Magento\Framework\UrlInterface::URL_TYPE_MEDIA) . SELF::CONFIG_IMAGE_DIR_PREFIX;
    }

    public function getBaseUrlStoresImage()
    {
        return $this->_storeManager->getStore()->getBaseUrl(\Magento\Framework\UrlInterface::URL_TYPE_MEDIA) . SELF::STORES_IMAGE_DIR_PREFIX;
    }

    public function getBaseUrl()
    {
        return $this->_storeManager->getStore()->getBaseUrl();
    }

    public function getViewFileUrl($fileId, array $params = [])
    {
        try {
            $params = array_merge(['_secure' => $this->request->isSecure()], $params);
            return $this->assetRepo->getUrlWithParams($fileId, $params);
        } catch (\Magento\Framework\Exception\LocalizedException $e) {
            return $this->urlBuilder->getUrl('', ['_direct' => 'core/index/notFound']);
        }
    }

//\Magento\Framework\App\ObjectManager::getInstance()
//->get('Psr\Log\LoggerInterface')->debug(print_r($model->getData(),true));
}
